@@ -134,6 +134,7 @@ int main (int argc, char** argv)
   //Initialize gnome-vfsmm:
   Gnome::Vfs::init();
  
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     //Gnome::Vfs::Transfer::transfer(input_uri_string, output_uri_string); //The simpler version, without progress feedback.
@@ -148,6 +149,23 @@ int main (int argc, char** argv)
     // if the operation was not successful, print the error and abort
     return print_error(ex);
   }
+#else
+  std::auto_ptr<Gnome::Vfs::exception> error;
+
+  //Gnome::Vfs::Transfer::transfer(input_uri_string, output_uri_string); //The simpler version, without progress feedback.
+  Gnome::Vfs::Transfer::transfer(input_uri_string, output_uri_string,
+     Gnome::Vfs::XFER_DEFAULT,
+     Gnome::Vfs::XFER_ERROR_MODE_QUERY,
+     Gnome::Vfs::XFER_OVERWRITE_MODE_QUERY,
+     sigc::ptr_fun(&on_transfer_progress),
+     error);
+
+  if(error.get())
+  {
+    // if the operation was not successful, print the error and abort
+    return print_error(*error.get());
+  }
+#endif //GLIBMM_EXCEPTIONS_ENABLED
   
   return 0;
 }
